==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/cs.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor v rámci federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Sdílení ze serveru na server není na tomto serveru povoleno",
    "Couldn't establish a federated share." : "Nepodařilo se ustavit federované sdílení.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit federované sdílení – možná je nesprávné heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požadavek na federované sdílení byl odeslán, obdržíte pozvánku. Podívejte se do upozornění pro vás.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení – vypadá to, že server, se kterým má být federováno, je příliš starý (Nextcloud verze 9 a starší).",
    "It is not allowed to send federated group shares from this server." : "Z tohoto serveru není povoleno posílat federovaná skupinová sdílení.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s účtem %2$s sdílena",
    "Not allowed to create a federated share to the same account" : "Není možné vytvářet federované sdílení mezi jedním a tím samým účtem",
    "Federated shares require read permissions" : "Propojené sdílení vyžaduje oprávnění ke čtení",
    "File is already shared with %s" : "Soubor už je sdílen s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %1$s se nezdařilo, %2$s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát.",
    "Could not find share" : "Nedaří se nalézt sdílení",
    "Federated sharing" : "Federované sdílení",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdrželi jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
    "You received {share} as a remote share from {user}" : "Obdrželi jste {share} jako vzdálené sdílení od {user}",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Federated Cloud Sharing" : "Sdílení v rámci federovaného cloudu",
    "Sharing" : "Sdílení",
    "Federated file sharing" : "Federované sdílení souborů",
    "Provide federated file sharing across servers" : "Poskytnout federované sdílení souborů napříč servery",
    "Confirm data upload to lookup server" : "Potvrdit nahrávání dat na vyhledávací server",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Pokud zapnuto, veškeré vlastnosti účtu (např. e-mailová adresa) s rozsahem viditelnosti nastavené na „zveřejněné“ budou automaticky synchronizovány a přenášeny do externího systému a veřejně k dispozici v globální adresáři kontaktů.",
    "Disable upload" : "Vypnout nahrávání",
    "Enable data upload" : "Zapnout nahrávání dat",
    "Confirm querying lookup server" : "Potvrdit dotazování vyhledávacího serveru",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Pokud zapnuto, obsah hledání při vytváření sdílení bude odeslán na externí systém, který poskytuje veřejný a globální adresář kontaktů.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Toto slouží k získávání identifikátorů v rámci federovaného cloudu pro usnadnění federovaného sdílení.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Dále mohou být pro ověření odeslány na server e-mailové adresy uživatelů.",
    "Disable querying" : "Vypnout dotazování",
    "Enable querying" : "Zapnout dotazování",
    "Unable to update federated files sharing config" : "Nedaří se aktualizovat nastavení federovaného sdílení souborů",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte, jak mohou lidé sdílet mezi servery. Týká se sdílení mezi lidmi na tomto serveru a stejně tak uživatelů federovaného sdílení.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Umožnit lidem na tomto serveru posílat sdílení na ostatní servery (tato volba také umožňuje WebDAV přístup k veřejným sdílením)",
    "Allow people on this server to receive shares from other servers" : "Povolit lidem na tomto serveru přijímat sdílení z jiných serverů",
    "Allow people on this server to send shares to groups on other servers" : "Povolit lidem na tomto serveru zasílat sdílení skupinám na ostatních serverech",
    "Allow people on this server to receive group shares from other servers" : "Povolit lidem na tomto serveru přijímat skupinová sdílení z jiných serverů",
    "The lookup server is only available for global scale." : "Vyhledávací server je k dispozici pouze pro globální měřítko.",
    "Search global and public address book for people" : "Vyhledávat lidi v globálním a veřejném adresáři kontaktů",
    "Allow people to publish their data to a global and public address book" : "Povolit lidem publikování jejich dat do globálního a sdíleného adresáře kontaktů",
    "Trusted federation" : "Důvěryhodná federace",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Ve výchozím nastavení automaticky přijímat sdílení od důvěryhodných federovaných účtů a skupin",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Sdílejte se mnou prostřednictvím mého #Nextcloud identifikátoru v rámci federovaného cloudu – více na {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sdílejte se mnou pomocí mého #Nextcloud identifikátoru v rámci federovaného cloudu",
    "Share with me via Nextcloud" : "Sdílet se mnou přes Nextcloud",
    "Cloud ID copied" : "Cloudový identifikátor zkopírován",
    "Copy" : "Zkopírovat",
    "Clipboard not available. Please copy the cloud ID manually." : "Schránka není k dispozici. Zkopírujte cloudový identifikátor ručně.",
    "Copied!" : "Zkopírováno",
    "Federated Cloud" : "Federovaný cloud",
    "Your Federated Cloud ID" : "Váš identifikátor v rámci fedorovaného cloudu",
    "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (dříve Twitter)",
    "formerly Twitter" : "dříve Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Přidat na svou webovou stránku",
    "HTML Code:" : "HTML kód:",
    "Cancel" : "Storno",
    "Add remote share" : "Přidat vzdálené sdílení",
    "Remote share" : "Vzdálené sdílení",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené sdílení {name} od {owner}@{remote}?",
    "Remote share password" : "Heslo ke vzdálenému sdílení",
    "Incoming share could not be processed" : "Příchozí sdílení se nepodařilo zpracovat",
    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/cs.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor v rámci federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Sdílení ze serveru na server není na tomto serveru povoleno",
    "Couldn't establish a federated share." : "Nepodařilo se ustavit federované sdílení.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit federované sdílení – možná je nesprávné heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požadavek na federované sdílení byl odeslán, obdržíte pozvánku. Podívejte se do upozornění pro vás.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení – vypadá to, že server, se kterým má být federováno, je příliš starý (Nextcloud verze 9 a starší).",
    "It is not allowed to send federated group shares from this server." : "Z tohoto serveru není povoleno posílat federovaná skupinová sdílení.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sdílení položky %1$s se nezdařilo, protože ta je už s účtem %2$s sdílena",
    "Not allowed to create a federated share to the same account" : "Není možné vytvářet federované sdílení mezi jedním a tím samým účtem",
    "Federated shares require read permissions" : "Propojené sdílení vyžaduje oprávnění ke čtení",
    "File is already shared with %s" : "Soubor už je sdílen s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %1$s se nezdařilo, %2$s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát.",
    "Could not find share" : "Nedaří se nalézt sdílení",
    "Federated sharing" : "Federované sdílení",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdrželi jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
    "You received {share} as a remote share from {user}" : "Obdrželi jste {share} jako vzdálené sdílení od {user}",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Federated Cloud Sharing" : "Sdílení v rámci federovaného cloudu",
    "Sharing" : "Sdílení",
    "Federated file sharing" : "Federované sdílení souborů",
    "Provide federated file sharing across servers" : "Poskytnout federované sdílení souborů napříč servery",
    "Confirm data upload to lookup server" : "Potvrdit nahrávání dat na vyhledávací server",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Pokud zapnuto, veškeré vlastnosti účtu (např. e-mailová adresa) s rozsahem viditelnosti nastavené na „zveřejněné“ budou automaticky synchronizovány a přenášeny do externího systému a veřejně k dispozici v globální adresáři kontaktů.",
    "Disable upload" : "Vypnout nahrávání",
    "Enable data upload" : "Zapnout nahrávání dat",
    "Confirm querying lookup server" : "Potvrdit dotazování vyhledávacího serveru",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Pokud zapnuto, obsah hledání při vytváření sdílení bude odeslán na externí systém, který poskytuje veřejný a globální adresář kontaktů.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Toto slouží k získávání identifikátorů v rámci federovaného cloudu pro usnadnění federovaného sdílení.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Dále mohou být pro ověření odeslány na server e-mailové adresy uživatelů.",
    "Disable querying" : "Vypnout dotazování",
    "Enable querying" : "Zapnout dotazování",
    "Unable to update federated files sharing config" : "Nedaří se aktualizovat nastavení federovaného sdílení souborů",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte, jak mohou lidé sdílet mezi servery. Týká se sdílení mezi lidmi na tomto serveru a stejně tak uživatelů federovaného sdílení.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Umožnit lidem na tomto serveru posílat sdílení na ostatní servery (tato volba také umožňuje WebDAV přístup k veřejným sdílením)",
    "Allow people on this server to receive shares from other servers" : "Povolit lidem na tomto serveru přijímat sdílení z jiných serverů",
    "Allow people on this server to send shares to groups on other servers" : "Povolit lidem na tomto serveru zasílat sdílení skupinám na ostatních serverech",
    "Allow people on this server to receive group shares from other servers" : "Povolit lidem na tomto serveru přijímat skupinová sdílení z jiných serverů",
    "The lookup server is only available for global scale." : "Vyhledávací server je k dispozici pouze pro globální měřítko.",
    "Search global and public address book for people" : "Vyhledávat lidi v globálním a veřejném adresáři kontaktů",
    "Allow people to publish their data to a global and public address book" : "Povolit lidem publikování jejich dat do globálního a sdíleného adresáře kontaktů",
    "Trusted federation" : "Důvěryhodná federace",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Ve výchozím nastavení automaticky přijímat sdílení od důvěryhodných federovaných účtů a skupin",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Sdílejte se mnou prostřednictvím mého #Nextcloud identifikátoru v rámci federovaného cloudu – více na {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sdílejte se mnou pomocí mého #Nextcloud identifikátoru v rámci federovaného cloudu",
    "Share with me via Nextcloud" : "Sdílet se mnou přes Nextcloud",
    "Cloud ID copied" : "Cloudový identifikátor zkopírován",
    "Copy" : "Zkopírovat",
    "Clipboard not available. Please copy the cloud ID manually." : "Schránka není k dispozici. Zkopírujte cloudový identifikátor ručně.",
    "Copied!" : "Zkopírováno",
    "Federated Cloud" : "Federovaný cloud",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá {productName} nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com",
    "Your Federated Cloud ID" : "Váš identifikátor v rámci fedorovaného cloudu",
    "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (dříve Twitter)",
    "formerly Twitter" : "dříve Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via {productName}" : "Nasdíleno mě prostřednictvím {productName}",
    "HTML Code:" : "HTML kód:",
    "Cancel" : "Storno",
    "Add remote share" : "Přidat vzdálené sdílení",
    "Remote share" : "Vzdálené sdílení",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené sdílení {name} od {owner}@{remote}?",
    "Remote share password" : "Heslo ke vzdálenému sdílení",
    "Incoming share could not be processed" : "Příchozí sdílení se nepodařilo zpracovat",
    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
